summaryrefslogtreecommitdiff
path: root/sc/source/ui/view/formatsh.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'sc/source/ui/view/formatsh.cxx')
-rw-r--r--sc/source/ui/view/formatsh.cxx4
1 files changed, 3 insertions, 1 deletions
diff --git a/sc/source/ui/view/formatsh.cxx b/sc/source/ui/view/formatsh.cxx
index 48ee79cafaac..dc685f4996e6 100644
--- a/sc/source/ui/view/formatsh.cxx
+++ b/sc/source/ui/view/formatsh.cxx
@@ -1165,7 +1165,7 @@ void ScFormatShell::ExecuteNumFormat( SfxRequest& rReq )
LanguageType eLanguage = pEntry->GetLanguage();
SvNumFormatType eType = pEntry->GetType();
//Just use eType to judge whether the command is fired for NUMBER/PERCENT/CURRENCY/SCIENTIFIC/FRACTION
//In sidebar, users can fire SID_NUMBER_FORMAT command by operating the related UI controls before they are disable
if(!(eType == SvNumFormatType::ALL
|| eType == SvNumFormatType::NUMBER
@@ -1176,6 +1176,8 @@ void ScFormatShell::ExecuteNumFormat( SfxRequest& rReq )
|| eType == (SvNumFormatType::CURRENCY | SvNumFormatType::DEFINED)
|| eType == SvNumFormatType::SCIENTIFIC
|| eType == (SvNumFormatType::SCIENTIFIC | SvNumFormatType::DEFINED)
+ || eType == SvNumFormatType::TIME
+ || eType == (SvNumFormatType::TIME | SvNumFormatType::DEFINED)
|| eType == SvNumFormatType::FRACTION
|| eType == (SvNumFormatType::FRACTION | SvNumFormatType::DEFINED)))
pEntry = nullptr;
@@ -1165,7 +1165,7 @@ void ScFormatShell::ExecuteNumFormat( SfxRequest& rReq )
LanguageType eLanguage = pEntry->GetLanguage();
SvNumFormatType eType = pEntry->GetType();
- //Just use eType to judge whether the command is fired for NUMBER/PERCENT/CURRENCY/SCIENTIFIC/FRACTION
+ //Just use eType to judge whether the command is fired for NUMBER/PERCENT/CURRENCY/SCIENTIFIC/FRACTION/TIME
//In sidebar, users can fire SID_NUMBER_FORMAT command by operating the related UI controls before they are disable
if(!(eType == SvNumFormatType::ALL